@@ -2,7 +2,7 @@ import logging
 from typing import Dict, Any, TypeVar
 import requests
 
-from schema_types import (
+from orcatech_python_api_client.schema_types import (
     ExternalSchemaType,
     GraphMapSchemaType,
     HistorySchemaType,
